IL-2 FB Dedicated Server Middleware
===================================

[![Build Status](https://travis-ci.org/IL2HorusTeam/il2ds-middleware.png)](https://travis-ci.org/IL2HorusTeam/il2ds-middleware)

Python library which provides high-level access to IL-2 FB Dedicated Server


Installation
------------

**Current version** of il2ds-middleware is **0.6.0**.

You can install it as a [PyPi package](https://pypi.python.org/pypi/il2ds-middleware/):

    pip install il2ds-middleware

